@@ -238,3 +238,30 @@ def test_singular_or_list(compiler):
     plan = compiler.compile(expr)
     (result,) = decompile(plan)
     assert result.equals(expr)
+
+
+def test_cast(compiler):
+    t = ibis.table([("bork32", dt.float32)], name="t")
+    expr = t[t.bork32.cast("float64").name("bork64")]
+    plan = compiler.compile(expr)
+    (result,) = decompile(plan)
+    assert result.equals(expr)
+
+
+@pytest.mark.xfail(
+    version.parse(ibis.__version__) < version.parse("3.0.0"),
+    reason="equality comparison of upcasted literals on ibis 2.x",
+)
+def test_searchedcase(compiler):
+    t = ibis.table(
+        [
+            ("bork32", dt.float32),
+            ("ork", dt.string),
+        ],
+        name="t",
+    )
+    t = t.filter([t.bork32 > 0.5])
+    expr = t.aggregate(t.ork.like("THING%").ifelse(t.bork32, 0).sum())
+    plan = compiler.compile(expr)
+    (result,) = decompile(plan)
+    assert result.equals(expr)
